@@ -96,7 +96,12 @@ class FoxgloveTestTemplates(FoxgloveTemplates):
             raise ValueError('context must include a "request" key')
         template = self.get_template(name)
         return CustomTemplateResponse(
-            template, context, status_code=status_code, headers=headers, media_type=media_type, background=background,
+            template,
+            context,
+            status_code=status_code,
+            headers=headers,
+            media_type=media_type,
+            background=background,
         )
 
 
